@@ -32,11 +32,9 @@ from .bindings import (
     BodyBinder,
     BoundValue,
     ControllerBinder,
-    ExactBinder,
     IdentityBinder,
     JSONBinder,
     QueryBinder,
-    RequestBinder,
     RouteBinder,
     ServiceBinder,
     empty,
@@ -280,11 +278,8 @@ def _get_parameter_binder(
 ) -> Binder:
     name = parameter.name
 
-    if name == "request":
-        return RequestBinder()
-
-    if name == "services":
-        return ExactBinder(services)
+    if name in Binder.aliases:
+        return Binder.aliases[name](services)
 
     original_annotation = parameter.annotation
 
@@ -297,6 +292,9 @@ def _get_parameter_binder(
     if isinstance(annotation, (str, ForwardRef)):  # pragma: no cover
         raise UnsupportedForwardRefInSignatureError(original_annotation)
 
+    if annotation in Binder.aliases:
+        return Binder.aliases[annotation](services)
+
     # 1. is the type annotation of BoundValue[T] type?
     if _is_bound_value_annotation(annotation):
         binder_type = get_binder_by_type(annotation)
@@ -495,9 +493,11 @@ def get_async_wrapper(
 
         return handler
 
-    if params_len == 1 and "request" in params:
-        # no need to wrap the request handler
-        return method
+    if params_len == 1:
+        param_name = list(params)[0]
+        if param_name in ("request", "websocket"):
+            # no need to wrap the request handler
+            return method
 
     binders = get_binders(route, services)
 
