@@ -9,18 +9,20 @@ from urllib.parse import unquote
 from blacksheep.utils import ensure_bytes, ensure_str
 
 __all__ = [
+    "HTTPMethod",
     "Router",
     "Route",
     "RouteMatch",
     "RouteDuplicate",
     "RegisteredRoute",
     "RoutesRegistry",
-    "HTTPMethod",
+    "RouteMethod",
 ]
 
 
-class HTTPMethod:
+class RouteMethod:
     GET = "GET"
+    GET_WS = "GET_WS"
     HEAD = "HEAD"
     POST = "POST"
     PUT = "PUT"
@@ -31,6 +33,10 @@ class HTTPMethod:
     PATCH = "PATCH"
 
 
+# for backward compatibility
+HTTPMethod = RouteMethod
+
+
 _route_all_rx = re.compile(b"\\*")
 _route_param_rx = re.compile(b"/:([^/]+)")
 _mustache_route_param_rx = re.compile(b"/{([^}]+)}")
@@ -86,7 +92,7 @@ class RouteMatch:
 
 
 def _get_parameter_pattern_fragment(
-    parameter_name: bytes, value_pattern: bytes = br"[^\/]+"
+    parameter_name: bytes, value_pattern: bytes = rb"[^\/]+"
 ) -> bytes:
     return b"/(?P<" + parameter_name + b">" + value_pattern + b")"
 
@@ -147,9 +153,9 @@ class Route:
                 )
 
             if b"/*" in pattern:
-                pattern = _route_all_rx.sub(br"?(?P<tail>.*)", pattern)
+                pattern = _route_all_rx.sub(rb"?(?P<tail>.*)", pattern)
             else:
-                pattern = _route_all_rx.sub(br"(?P<tail>.*)", pattern)
+                pattern = _route_all_rx.sub(rb"(?P<tail>.*)", pattern)
 
         # support for < > patterns, e.g. /api/cats/<cat_id>
         # but also: /api/cats/<int:cat_id> or /api/cats/<uuid:cat_id> for more
@@ -167,7 +173,7 @@ class Route:
 
         # route parameters defined using /:name syntax
         if b"/:" in pattern:
-            pattern = _route_param_rx.sub(br"/(?P<\1>[^\/]+)", pattern)
+            pattern = _route_param_rx.sub(rb"/(?P<\1>[^\/]+)", pattern)
 
         # NB: following code is just to throw user friendly errors;
         # regex would fail anyway, but with a more complex message
@@ -243,7 +249,7 @@ class Route:
 
     @property
     def mustache_pattern(self) -> str:
-        return _route_param_rx.sub(br"/{\1}", self.pattern).decode("utf8")
+        return _route_param_rx.sub(rb"/{\1}", self.pattern).decode("utf8")
 
     @property
     def full_pattern(self) -> bytes:
@@ -295,58 +301,64 @@ class RouterBase:
         return decorator
 
     def add_head(self, pattern: str, handler: Callable[..., Any]) -> None:
-        self.add(HTTPMethod.HEAD, pattern, handler)
+        self.add(RouteMethod.HEAD, pattern, handler)
 
     def add_get(self, pattern: str, handler: Callable[..., Any]) -> None:
-        self.add(HTTPMethod.GET, pattern, handler)
+        self.add(RouteMethod.GET, pattern, handler)
 
     def add_post(self, pattern: str, handler: Callable[..., Any]) -> None:
-        self.add(HTTPMethod.POST, pattern, handler)
+        self.add(RouteMethod.POST, pattern, handler)
 
     def add_put(self, pattern: str, handler: Callable[..., Any]) -> None:
-        self.add(HTTPMethod.PUT, pattern, handler)
+        self.add(RouteMethod.PUT, pattern, handler)
 
     def add_delete(self, pattern: str, handler: Callable[..., Any]) -> None:
-        self.add(HTTPMethod.DELETE, pattern, handler)
+        self.add(RouteMethod.DELETE, pattern, handler)
 
     def add_trace(self, pattern: str, handler: Callable[..., Any]) -> None:
-        self.add(HTTPMethod.TRACE, pattern, handler)
+        self.add(RouteMethod.TRACE, pattern, handler)
 
     def add_options(self, pattern: str, handler: Callable[..., Any]) -> None:
-        self.add(HTTPMethod.OPTIONS, pattern, handler)
+        self.add(RouteMethod.OPTIONS, pattern, handler)
 
     def add_connect(self, pattern: str, handler: Callable[..., Any]) -> None:
-        self.add(HTTPMethod.CONNECT, pattern, handler)
+        self.add(RouteMethod.CONNECT, pattern, handler)
 
     def add_patch(self, pattern: str, handler: Callable[..., Any]) -> None:
-        self.add(HTTPMethod.PATCH, pattern, handler)
+        self.add(RouteMethod.PATCH, pattern, handler)
+
+    def add_ws(self, pattern: str, handler: Callable[..., Any]) -> None:
+        self.add(RouteMethod.GET_WS, pattern, handler)
 
     def head(self, pattern: Optional[str] = "/") -> Callable[..., Any]:
-        return self.get_decorator(HTTPMethod.HEAD, pattern)
+        return self.get_decorator(RouteMethod.HEAD, pattern)
 
     def get(self, pattern: Optional[str] = "/") -> Callable[..., Any]:
-        return self.get_decorator(HTTPMethod.GET, pattern)
+        return self.get_decorator(RouteMethod.GET, pattern)
 
     def post(self, pattern: Optional[str] = "/") -> Callable[..., Any]:
-        return self.get_decorator(HTTPMethod.POST, pattern)
+        return self.get_decorator(RouteMethod.POST, pattern)
 
     def put(self, pattern: Optional[str] = "/") -> Callable[..., Any]:
-        return self.get_decorator(HTTPMethod.PUT, pattern)
+        return self.get_decorator(RouteMethod.PUT, pattern)
 
     def delete(self, pattern: Optional[str] = "/") -> Callable[..., Any]:
-        return self.get_decorator(HTTPMethod.DELETE, pattern)
+        return self.get_decorator(RouteMethod.DELETE, pattern)
 
     def trace(self, pattern: Optional[str] = "/") -> Callable[..., Any]:
-        return self.get_decorator(HTTPMethod.TRACE, pattern)
+        return self.get_decorator(RouteMethod.TRACE, pattern)
 
     def options(self, pattern: Optional[str] = "/") -> Callable[..., Any]:
-        return self.get_decorator(HTTPMethod.OPTIONS, pattern)
+        return self.get_decorator(RouteMethod.OPTIONS, pattern)
 
     def connect(self, pattern: Optional[str] = "/") -> Callable[..., Any]:
-        return self.get_decorator(HTTPMethod.CONNECT, pattern)
+        return self.get_decorator(RouteMethod.CONNECT, pattern)
 
     def patch(self, pattern: Optional[str] = "/") -> Callable[..., Any]:
-        return self.get_decorator(HTTPMethod.PATCH, pattern)
+        return self.get_decorator(RouteMethod.PATCH, pattern)
+
+    def ws(self, pattern) -> Callable[..., Any]:
+        return self.get_decorator(RouteMethod.GET_WS, pattern)
 
 
 class Router(RouterBase):
@@ -437,6 +449,9 @@ class Router(RouterBase):
 
         return RouteMatch(self._fallback, None)
 
+    def get_ws_match(self, value: AnyStr) -> Optional[RouteMatch]:
+        return self.get_match(RouteMethod.GET_WS, value)
+
     @lru_cache(maxsize=1200)
     def get_matching_route(self, method: AnyStr, value: AnyStr) -> Optional[Route]:
         for route in self.routes[ensure_bytes(method)]:
